@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -744,7 +744,7 @@ file_open_edit (const gchar *file)
   page_num = orz_mdi_append_page (ORZ_MDI (mdi),
                                             scroll, filename, !file, mmaid);
   gtk_widget_show_all (scroll);
-  gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page_num);
+  gtk_notebook_set_current_page (GTK_NOTEBOOK (mdi), page_num);
   gtk_widget_grab_focus (mmaid->list);
 
   /* ja:新規作成ではなく、ファイルが存在する時には履歴に加える */
